import {Link, Stack, Typography, useMediaQuery, useTheme} from "@mui/material";
import PrivacyImage from "@/common/assets/images/legal/privacy.svg";

export const Privacy = () => {
    const theme = useTheme();
    const isMobile = useMediaQuery(theme.breakpoints.down("lg"));

    return (
        <Stack direction="column" justifyContent="center"
               sx={{mt: 15, ml: {lg: "auto", xs: "0"}, mr: {lg: "auto", xs: "0"}, width: {lg: "80%", xs: "100%"}}}>
            <Stack direction="row" justifyContent="space-between">
                <Stack direction="column" justifyContent="center" sx={{width: "40rem", overflow: "hidden",
                    textOverflow: "ellipsis"}}>
                    <Typography fontWeight={700} variant={isMobile ? "h3" : "h2"}>Datenschutz</Typography>
                    <Typography fontWeight={500} variant={isMobile ? "h5" : "h4"}>Unsere Datenschutzerklärung</Typography>

                    <Typography variant="h6" fontWeight={500} sx={{mt: 5}}>
                        Datenschutz hat einen besonders hohen Stellenwert für uns.
                        Mit den folgenden Hinweisen möchten wir Sie ausführlich über den Umgang mit Ihren Daten informieren.
                    </Typography>
                </Stack>

                {!isMobile && <img src={PrivacyImage} alt="Privacy" height={400}/>}
            </Stack>

            <Stack sx={{mt: 10}} gap={2.5}>
                <Typography variant="h4" fontWeight={700}>Allgemeine Hinweise</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Die folgenden Hinweise geben einen einfachen Überblick darüber, was mit Ihren personenbezogenen
                    Daten passiert, wenn Sie diese Website besuchen. Personenbezogene Daten sind alle Daten, mit denen
                    Sie persönlich identifiziert werden können. Ausführliche Informationen zum Thema Datenschutz
                    entnehmen Sie unserer unter diesem Text aufgeführten Datenschutzerklärung.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Datenerfassung auf dieser Website</Typography>
                <Typography variant="body1" fontWeight={500}>
                    <Typography variant="h5" fontWeight={600}>Wer ist verantwortlich für die Datenerfassung auf dieser Website?</Typography>
                    Die Datenverarbeitung auf dieser Website erfolgt durch den Websitebetreiber. Dessen Kontaktdaten
                    können Sie dem Impressum dieser Website entnehmen.
                </Typography>

                <Typography variant="body1" fontWeight={500}>
                    <Typography variant="h5" fontWeight={600}>Wie erfassen wir Ihre Daten?</Typography>
                    Ihre Daten werden zum einen dadurch erhoben, dass Sie uns diese mitteilen. Hierbei kann es sich
                    z. B. um Daten handeln, die Sie in ein Kontaktformular eingeben.
                    <br/>
                    Andere Daten werden automatisch oder nach Ihrer Einwilligung beim Besuch der Website durch unsere
                    IT-Systeme erfasst. Das sind vor allem technische Daten (z. B. Internetbrowser, Betriebssystem oder
                    Uhrzeit des Seitenaufrufs). Die Erfassung dieser Daten erfolgt automatisch, sobald Sie diese Website
                    betreten.
                </Typography>

                <Typography variant="body1" fontWeight={500}>
                    <Typography variant="h5" fontWeight={600}>Wofür nutzen wir Ihre Daten?</Typography>
                    Ein Teil der Daten wird erhoben, um eine fehlerfreie Bereitstellung der Website zu gewährleisten.
                    Andere Daten können zur Analyse Ihres Nutzerverhaltens verwendet werden.
                </Typography>

                <Typography variant="body1" fontWeight={500}>
                    <Typography variant="h5" fontWeight={600}>Welche Rechte haben Sie bezüglich Ihrer Daten?</Typography>
                    Sie haben jederzeit das Recht, unentgeltlich Auskunft über Herkunft, Empfänger und Zweck Ihrer
                    gespeicherten personenbezogenen Daten zu erhalten. Sie haben außerdem ein Recht, die Berichtigung
                    oder Löschung dieser Daten zu verlangen. Wenn Sie eine Einwilligung zur Datenverarbeitung erteilt
                    haben, können Sie diese Einwilligung jederzeit für die Zukunft widerrufen. Außerdem haben Sie das
                    Recht, unter bestimmten Umständen die Einschränkung der Verarbeitung Ihrer personenbezogenen Daten
                    zu verlangen. Des Weiteren steht Ihnen ein Beschwerderecht bei der zuständigen Aufsichtsbehörde zu.
                    <br/>
                    Hierzu sowie zu weiteren Fragen zum Thema Datenschutz können Sie sich jederzeit an uns wenden.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Datenschutz</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Die Betreiber dieser Seiten nehmen den Schutz Ihrer persönlichen Daten sehr ernst. Wir behandeln
                    Ihre personenbezogenen Daten vertraulich und entsprechend den gesetzlichen Datenschutzvorschriften
                    sowie dieser Datenschutzerklärung.
                    Wenn Sie diese Website benutzen, werden verschiedene personenbezogene Daten erhoben. Personenbezogene
                    Daten sind Daten, mit denen Sie persönlich identifiziert werden können. Die vorliegende
                    Datenschutzerklärung erläutert, welche Daten wir erheben und wofür wir sie nutzen. Sie erläutert
                    auch, wie und zu welchem Zweck das geschieht.

                    Wir weisen darauf hin, dass die Datenübertragung im Internet (z. B. bei der Kommunikation per E-Mail)
                    Sicherheitslücken aufweisen kann. Ein lückenloser Schutz der Daten vor dem Zugriff durch Dritte ist
                    nicht möglich.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Hinweis zur verantwortlichen Stelle</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Die verantwortliche Stelle für die Datenverarbeitung auf dieser Website ist:
                    <br/><br/>
                    Leon Fleß<br/>
                    Eichendorffstraße 5<br/>
                    91301 Forchheim<br/>
                    Deutschland
                    <br/><br/>
                    E-Mail: leon@licenseapi.de
                    <br/><br/>
                    Verantwortliche Stelle ist die natürliche oder juristische Person, die allein oder gemeinsam mit
                    anderen über die Zwecke und Mittel der Verarbeitung von personenbezogenen Daten (z. B. Namen,
                    E-Mail-Adressen o. Ä.) entscheidet.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Speicherdauer</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Soweit innerhalb dieser Datenschutzerklärung keine speziellere Speicherdauer genannt wurde,
                    verbleiben Ihre personenbezogenen Daten bei uns, bis der Zweck für die Datenverarbeitung entfällt.
                    Wenn Sie ein berechtigtes Löschersuchen geltend machen oder eine Einwilligung zur Datenverarbeitung
                    widerrufen, werden Ihre Daten gelöscht, sofern wir keine anderen rechtlich zulässigen Gründe für die
                    Speicherung Ihrer personenbezogenen Daten haben (z. B. steuer- oder handelsrechtliche
                    Aufbewahrungsfristen); im letztgenannten Fall erfolgt die Löschung nach Fortfall dieser Gründe.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Allgemeine Hinweise zu den Rechtsgrundlagen der
                    Datenverarbeitung auf dieser Website</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Sofern Sie in die Datenverarbeitung eingewilligt haben, verarbeiten wir Ihre personenbezogenen Daten
                    auf Grundlage von Art. 6 Abs. 1 lit. a DSGVO bzw. Art. 9 Abs. 2 lit. a DSGVO, sofern besondere
                    Datenkategorien nach Art. 9 Abs. 1 DSGVO verarbeitet werden. Im Falle einer ausdrücklichen
                    Einwilligung in die Übertragung personenbezogener Daten in Drittstaaten erfolgt die Datenverarbeitung
                    außerdem auf Grundlage von Art. 49 Abs. 1 lit. a DSGVO. Sofern Sie in die Speicherung von Cookies oder
                    in den Zugriff auf Informationen in Ihr Endgerät (z. B. via Device-Fingerprinting) eingewilligt haben,
                    erfolgt die Datenverarbeitung zusätzlich auf Grundlage von § 25 Abs. 1 TTDSG. Die Einwilligung ist
                    jederzeit widerrufbar. Sind Ihre Daten zur Vertragserfüllung oder zur Durchführung vorvertraglicher
                    Maßnahmen erforderlich, verarbeiten wir Ihre Daten auf Grundlage des Art. 6 Abs. 1 lit. b DSGVO. Des
                    Weiteren verarbeiten wir Ihre Daten, sofern diese zur Erfüllung einer rechtlichen Verpflichtung
                    erforderlich sind auf Grundlage von Art. 6 Abs. 1 lit. c DSGVO. Die Datenverarbeitung kann ferner
                    auf Grundlage unseres berechtigten Interesses nach Art. 6 Abs. 1 lit. f DSGVO erfolgen. Über die
                    jeweils im Einzelfall einschlägigen Rechtsgrundlagen wird in den folgenden Absätzen dieser
                    Datenschutzerklärung informiert.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Widerruf Ihrer Einwilligung zur Datenverarbeitung</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Viele Datenverarbeitungsvorgänge sind nur mit Ihrer ausdrücklichen Einwilligung möglich. Sie können
                    eine bereits erteilte Einwilligung jederzeit widerrufen. Die Rechtmäßigkeit der bis zum Widerruf
                    erfolgten Datenverarbeitung bleibt vom Widerruf unberührt.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Widerspruchsrecht gegen die Datenerhebung in besonderen Fällen
                    sowie gegen Direktwerbung (Art. 21 DSGVO)</Typography>
                <Typography variant="body1" fontWeight={500}>
                    WENN DIE DATENVERARBEITUNG AUF GRUNDLAGE VON ART. 6 ABS. 1 LIT. E ODER F DSGVO ERFOLGT, HABEN SIE
                    JEDERZEIT DAS RECHT, AUS GRÜNDEN, DIE SICH AUS IHRER BESONDEREN SITUATION ERGEBEN, GEGEN DIE
                    VERARBEITUNG IHRER PERSONENBEZOGENEN DATEN WIDERSPRUCH EINZULEGEN; DIES GILT AUCH FÜR EIN AUF DIESE
                    BESTIMMUNGEN GESTÜTZTES PROFILING. DIE JEWEILIGE RECHTSGRUNDLAGE, AUF DENEN EINE VERARBEITUNG BERUHT,
                    ENTNEHMEN SIE DIESER DATENSCHUTZERKLÄRUNG. WENN SIE WIDERSPRUCH EINLEGEN, WERDEN WIR IHRE BETROFFENEN
                    PERSONENBEZOGENEN DATEN NICHT MEHR VERARBEITEN, ES SEI DENN, WIR KÖNNEN ZWINGENDE SCHUTZWÜRDIGE GRÜNDE
                    FÜR DIE VERARBEITUNG NACHWEISEN, DIE IHRE INTERESSEN, RECHTE UND FREIHEITEN ÜBERWIEGEN ODER DIE
                    VERARBEITUNG DIENT DER GELTENDMACHUNG, AUSÜBUNG ODER VERTEIDIGUNG VON RECHTSANSPRÜCHEN (WIDERSPRUCH
                    NACH ART. 21 ABS. 1 DSGVO).
                    <br/><br/>
                    WERDEN IHRE PERSONENBEZOGENEN DATEN VERARBEITET, UM DIREKTWERBUNG ZU BETREIBEN, SO HABEN SIE DAS RECHT,
                    JEDERZEIT WIDERSPRUCH GEGEN DIE VERARBEITUNG SIE BETREFFENDER PERSONENBEZOGENER DATEN ZUM ZWECKE
                    DERARTIGER WERBUNG EINZULEGEN; DIES GILT AUCH FÜR DAS PROFILING, SOWEIT ES MIT SOLCHER DIREKTWERBUNG
                    IN VERBINDUNG STEHT. WENN SIE WIDERSPRECHEN, WERDEN IHRE PERSONENBEZOGENEN DATEN ANSCHLIESSEND NICHT
                    MEHR ZUM ZWECKE DER DIREKTWERBUNG VERWENDET (WIDERSPRUCH NACH ART. 21 ABS. 2 DSGVO).
                </Typography>

                <Typography variant="h4" fontWeight={700}>Beschwerderecht bei der zuständigen Aufsichtsbehörde</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Im Falle von Verstößen gegen die DSGVO steht den Betroffenen ein Beschwerderecht bei einer
                    Aufsichtsbehörde, insbesondere in dem Mitgliedstaat ihres gewöhnlichen Aufenthalts, ihres
                    Arbeitsplatzes oder des Orts des mutmaßlichen Verstoßes zu. Das Beschwerderecht besteht unbeschadet
                    anderweitiger verwaltungsrechtlicher oder gerichtlicher Rechtsbehelfe.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Recht auf Datenübertragbarkeit</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Sie haben das Recht, Daten, die wir auf Grundlage Ihrer Einwilligung oder in Erfüllung eines Vertrags
                    automatisiert verarbeiten, an sich oder an einen Dritten in einem gängigen, maschinenlesbaren Format
                    aushändigen zu lassen. Sofern Sie die direkte Übertragung der Daten an einen anderen Verantwortlichen
                    verlangen, erfolgt dies nur, soweit es technisch machbar ist.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Auskunft, Berichtigung und Löschung</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Sie haben im Rahmen der geltenden gesetzlichen Bestimmungen jederzeit das Recht auf unentgeltliche
                    Auskunft über Ihre gespeicherten personenbezogenen Daten, deren Herkunft und Empfänger und den Zweck
                    der Datenverarbeitung und ggf. ein Recht auf Berichtigung oder Löschung dieser Daten. Hierzu sowie
                    zu weiteren Fragen zum Thema personenbezogene Daten können Sie sich jederzeit an uns wenden.
                </Typography>

                <Typography variant="h4" fontWeight={700}>Recht auf Einschränkung der Verarbeitung</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Sie haben das Recht, die Einschränkung der Verarbeitung Ihrer personenbezogenen Daten zu verlangen.
                    Hierzu können Sie sich jederzeit an uns wenden. Das Recht auf Einschränkung der Verarbeitung besteht
                    in folgenden Fällen:
                    <br/><br/>

                    <ul>
                        <li>
                            Wenn Sie die Richtigkeit Ihrer bei uns gespeicherten personenbezogenen Daten bestreiten,
                            benötigen wir in der Regel Zeit, um dies zu überprüfen. Für die Dauer der Prüfung haben Sie
                            das Recht, die Einschränkung der Verarbeitung Ihrer personenbezogenen Daten zu verlangen.
                        </li>
                        <li>
                            Wenn die Verarbeitung Ihrer personenbezogenen Daten unrechtmäßig geschah/geschieht, können
                            Sie statt der Löschung die Einschränkung der Datenverarbeitung verlangen.
                        </li>
                        <li>
                            Wenn wir Ihre personenbezogenen Daten nicht mehr benötigen, Sie sie jedoch zur Ausübung,
                            Verteidigung oder Geltendmachung von Rechtsansprüchen benötigen, haben Sie das Recht, statt
                            der Löschung die Einschränkung der Verarbeitung Ihrer personenbezogenen Daten zu verlangen.
                        </li>
                        <li>
                            Wenn Sie einen Widerspruch nach Art. 21 Abs. 1 DSGVO eingelegt haben, muss eine Abwägung
                            zwischen Ihren und unseren Interessen vorgenommen werden. Solange noch nicht feststeht,
                            wessen Interessen überwiegen, haben Sie das Recht, die Einschränkung der Verarbeitung Ihrer
                            personenbezogenen Daten zu verlangen.
                        </li>
                    </ul>
                    Wenn Sie die Verarbeitung Ihrer personenbezogenen Daten eingeschränkt haben, dürfen diese Daten –
                    von ihrer Speicherung abgesehen – nur mit Ihrer Einwilligung oder zur Geltendmachung, Ausübung
                    oder Verteidigung von Rechtsansprüchen oder zum Schutz der Rechte einer anderen natürlichen oder
                    juristischen Person oder aus Gründen eines wichtigen öffentlichen Interesses der Europäischen Union
                    oder eines Mitgliedstaats verarbeitet werden.
                </Typography>

                <Typography variant="h4" fontWeight={700}>SSL- bzw. TLS-Verschlüsselung</Typography>
                <Typography variant="body1" fontWeight={500}>
                    Diese Seite nutzt aus Sicherheitsgründen und zum Schutz der Übertragung vertraulicher Inhalte, wie
                    zum Beispiel Bestellungen oder Anfragen, die Sie an uns als Seitenbetreiber senden, eine SSL- bzw.
                    TLS-Verschlüsselung. Eine verschlüsselte Verbindung erkennen Sie daran, dass die Adresszeile des
                    Browsers von „http://“ auf „https://“ wechselt und an dem Schloss-Symbol in Ihrer Browserzeile.
                </Typography>

                <Typography variant="body1" fontWeight={500}>
                    Quelle: <Link href="https://www.e-recht24.de">e-recht24.de</Link>
                </Typography>



            </Stack>
        </Stack>
    )
}